#ifndef ASSIMP_REVISION_H_INC
#define ASSIMP_REVISION_H_INC

#define GitVersion 0x8f0c6b0
#define GitBranch "HEAD"

#endif // ASSIMP_REVISION_H_INC
